@@ -6,7 +6,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.core.urlresolvers import reverse_lazy
 from django.template.loader import render_to_string
 from django.utils.html import strip_tags
-
+from django.contrib.sites.models import Site
 
 def es_suyo(usuario, id):
 
@@ -82,25 +82,35 @@ def grupo_moderadores(usuario):
 
 def mysendmail(email, mytype, arguments):
 
+    current_site = Site.objects.get_current()
+
     # favour django-mailer but fall back to django.core.mail
     if "mailer" in conf.INSTALLED_APPS:
         from mailer import send_mail
+        from mailer import send_html_mail
     else:
         from django.core.mail import send_mail
+        from django.core.mail import send_mail as send_html_mail
 
     if mytype == 'newpost':
         subject =  _('[%s] New post in "%s"') % (conf.SITE_TITLE, arguments[0])
         from_email = conf.DEFAULT_FROM_EMAIL
         to = email
-        html_content = render_to_string('rforum/email_subscribers_newpost.html', {'title': arguments[0], 'slug': arguments[1]})
+        html_content = render_to_string('rforum/email_subscribers_newpost.html',
+                                        {'title': arguments[0],
+                                        'slug': arguments[1],
+                                        'domain': current_site.domain })
         text_content = strip_tags(html_content)
 
     if mytype == 'inappropiate':
         subject =  _('[%s] Post marked as inappropiate') % (conf.SITE_TITLE)
         from_email = conf.DEFAULT_FROM_EMAIL
         to = email
-        html_content = render_to_string('rforum/email_inappropiate.html', {'slug': arguments[0]})
+        html_content = render_to_string('rforum/email_inappropiate.html',
+                                        {'slug': arguments[0],
+                                        'domain': current_site.domain })
         text_content = strip_tags(html_content)
 
-    send_mail(subject, html_content, from_email, [to])
+    send_html_mail(subject, text_content, html_content, from_email, [to])
+
 
