@@ -242,19 +242,10 @@ class PostCreate(CreateView):
         form.instance.status = 1
         form.instance.date_created = datetime.now()
         form.instance.topic = get_object_or_404(mymodels.Topic, slug=self.kwargs['slug'], closed=0)
+        form.instance.topic.add_subscriber(self.request.user)
         """ DEACTIVED: Email subscribers when a new comment is posted """
         for subscriber in form.instance.topic.subscribers.all():
             utils.mysendmail(subscriber.email, 'newpost', [form.instance.topic.title, form.instance.topic.slug])
-        #    subject =  _('[%s] New post in a thread you\'re subscribed') % (conf.SITE_TITLE)
-        #    from_email = conf.DEFAULT_FROM_EMAIL
-        #    to = subscriber.email
-
-        #    html_content = render_to_string('rforum/email_subscribers_newpost.html', {'foo': 'bar'})
-        #    text_content = strip_tags(html_content)
-
-        #    msg = EmailMultiAlternatives(subject, text_content, from_email, [to])
-        #    msg.attach_alternative(html_content, "text/html")
-        #    msg.send()
         return super(PostCreate, self).form_valid(form)
 
     def get_context_data(self, **kwargs):
